# pep621

[![pre-commit.ci status](https://results.pre-commit.ci/badge/github/FFY00/python-pep621/main.svg)](https://results.pre-commit.ci/latest/github/FFY00/python-pep621/main)
[![checks](https://github.com/FFY00/python-pep621/actions/workflows/checks.yml/badge.svg)](https://github.com/FFY00/python-pep621/actions/workflows/checks.yml)
[![tests](https://github.com/FFY00/python-pep621/actions/workflows/tests.yml/badge.svg)](https://github.com/FFY00/python-pep621/actions/workflows/tests.yml)
[![codecov](https://codecov.io/gh/FFY00/python-pep621/branch/main/graph/badge.svg?token=9chBjS1lch)](https://codecov.io/gh/FFY00/python-pep621)
[![Documentation Status](https://readthedocs.org/projects/pep621/badge/?version=latest)](https://pep621.readthedocs.io/en/latest/?badge=latest)

PEP 621 metadata parsing.
